<?xml version="1.0" ?><!DOCTYPE TS><TS version="2.1" language="it">
<context>
    <name>Bubble</name>
    <message>
        <source>1 new message</source>
        <translation>1 nuovo messaggio</translation>
    </message>
</context>
<context>
    <name>dde::network::NetAirplaneModeTipsItem</name>
    <message>
        <source>Disable &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;Airplane Mode&lt;/a&gt; first if you want to connect to a wireless network</source>
        <translation>Disattiva &lt;a style=&quot;text-decoration: none;&quot; href=&quot;Airplane Mode&quot;&gt;la modalità aereo&lt;/a&gt; se desideri collegarti ad una rete wireless</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerPrivate</name>
    <message>
        <source>IP conflict</source>
        <translation>Conflitto IP</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
</context>
<context>
    <name>dde::network::NetManagerThreadPrivate</name>
    <message>
        <source>Wired Connection %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN L2TP %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN PPTP %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN VPNC %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN OpenVPN %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN StrongSwan %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>VPN OpenConnect %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>PPPoE Connection %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connecting &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; connected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>&quot;%1&quot; disconnected</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please check your router or net cable.</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Unable to connect &quot;%1&quot;, please keep closer to the wireless router</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connection failed, unable to connect &quot;%1&quot;, wrong password</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Password is required to connect &quot;%1&quot;</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>The &quot;%1&quot; 802.11 WLAN network could not be found</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>To connect &quot;%1&quot;, please set up your authentication info after logging in</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetSecretWidget</name>
    <message>
        <source>Password</source>
        <translation>Password</translation>
    </message>
    <message>
        <source>Private Pwd</source>
        <translation>Password Privata</translation>
    </message>
    <message>
        <source>key</source>
        <translation>Chiave</translation>
    </message>
    <message>
        <source>Proxy Password</source>
        <translation>Password Proxy</translation>
    </message>
    <message>
        <source>Group Password</source>
        <translation>Password di Gruppo</translation>
    </message>
    <message>
        <source>Username</source>
        <translation>Nome utente</translation>
    </message>
    <message>
        <source>Name (SSID)</source>
        <translation>Nome (SSID)</translation>
    </message>
    <message>
        <source>Cancel</source>
        <comment>button</comment>
        <translation>Annulla</translation>
    </message>
    <message>
        <source>Connect</source>
        <comment>button</comment>
        <translation>Connetti</translation>
    </message>
</context>
<context>
    <name>dde::network::NetStatus</name>
    <message>
        <source>Disable wired connection</source>
        <translation>Disabilita connessione cablata</translation>
    </message>
    <message>
        <source>Enable wired connection</source>
        <translation>Abilita connessione cablata</translation>
    </message>
    <message>
        <source>Disable wireless connection</source>
        <translation>Disabilita connessione WiFi</translation>
    </message>
    <message>
        <source>Enable wireless connection</source>
        <translation>Abilita connessione WiFi</translation>
    </message>
    <message>
        <source>Disable network</source>
        <translation>Disabilita Rete</translation>
    </message>
    <message>
        <source>Enable network</source>
        <translation>Abilita Rete</translation>
    </message>
    <message>
        <source>Disable VPN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable VPN</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Disable system proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Enable system proxy</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Network settings</source>
        <translation>Impostazioni Rete</translation>
    </message>
    <message>
        <source>Multiple services started</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connected to: %1</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>System proxy enabled</source>
        <translation type="unfinished"/>
    </message>
    <message>
        <source>Connected</source>
        <translation>Connesso</translation>
    </message>
    <message>
        <source>Network off</source>
        <translation>Rete disattivata</translation>
    </message>
    <message>
        <source>Network cable unplugged</source>
        <translation>Cavo di rete scollegato</translation>
    </message>
    <message>
        <source>Not connected</source>
        <translation>Non connesso</translation>
    </message>
    <message>
        <source>Connecting</source>
        <translation>Connessione in corso</translation>
    </message>
    <message>
        <source>Connected but no Internet access</source>
        <translation>Connesso senza accesso ad internet</translation>
    </message>
    <message>
        <source>Connection failed</source>
        <translation>Connessione fallita</translation>
    </message>
    <message>
        <source>IP conflict</source>
        <translation>Conflitto IP</translation>
    </message>
    <message>
        <source>Wireless Network</source>
        <translation>Rete wireless</translation>
    </message>
    <message>
        <source>Connected %1</source>
        <translation>Connesso a %1</translation>
    </message>
    <message>
        <source>Off</source>
        <translation>Spento</translation>
    </message>
    <message>
        <source>Wired Network</source>
        <translation>Rete cablata</translation>
    </message>
    <message>
        <source>Network</source>
        <translation>Rete</translation>
    </message>
</context>
<context>
    <name>dde::network::NetSystemProxyControlItem</name>
    <message>
        <source>System Proxy</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetVPNTipsItem</name>
    <message>
        <source>VPN configuration is not connected or failed to connect. Please &lt;a style=&quot;text-decoration: none;&quot; href=&quot;go to the control center&quot;&gt;go to the control center&lt;/a&gt; for inspection.</source>
        <translation type="unfinished"/>
    </message>
</context>
<context>
    <name>dde::network::NetWiredControlItem</name>
    <message>
        <source>Wired Network</source>
        <translation>Connessione cablata</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessControlItem</name>
    <message>
        <source>Wireless Network</source>
        <translation>Connessione WiFi</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessHiddenItem</name>
    <message>
        <source>Connect to hidden network</source>
        <translation>Connetti ad una rete nascosta</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessMineItem</name>
    <message>
        <source>My Networks</source>
        <translation>Le mie Reti</translation>
    </message>
</context>
<context>
    <name>dde::network::NetWirelessOtherItem</name>
    <message>
        <source>Other Networks</source>
        <translation>Altre Reti</translation>
    </message>
</context>
</TS>